@@ -1,4 +1,5 @@
 from abc import abstractmethod
+from pymongo.collection import ReturnDocument
 
 from deci_common.abstractions.abstract_logger import ILogger
 
@@ -21,7 +22,13 @@ class AbstractDocumentDBConnector(ILogger):
         raise NotImplementedError()
 
     @abstractmethod
-    def _update_and_return_document(self, search_filter: dict, updated_document: dict, upsert: bool = False):
+    def _update_and_return_document(
+        self,
+        search_filter: dict,
+        updated_document: dict,
+        upsert: bool = False,
+        return_document: ReturnDocument = ReturnDocument.BEFORE,
+    ):
         raise NotImplementedError()
 
     @abstractmethod
