@@ -1,9 +1,10 @@
 import datetime
 from abc import ABCMeta
-from typing import Type, Dict, Any
+from typing import Type, Dict, Any, List
 
 from pymongo import MongoClient
 from pymongo.collection import Collection
+from pymongo.command_cursor import CommandCursor
 from pymongo.cursor import Cursor
 from pymongo.collection import ReturnDocument
 
@@ -125,6 +126,22 @@ class MongoDBConnector(AbstractDocumentDBConnector):
             filter=search_filter, update={"$set": updated_document}, upsert=upsert, return_document=return_document
         )
 
+    def _update_many_and_return_documents(
+        self,
+        search_filter: Dict[str, Any],
+        updated_document: Dict[str, Any],
+        upsert: bool = False,
+    ) -> Cursor:
+        updated_document.update({"update_time": datetime.datetime.utcnow()})
+        collection = self._get_collection()
+        collection.update_many(
+            filter=search_filter,
+            update={"$set": updated_document},
+            upsert=upsert,
+        )
+        search_filter.update(updated_document)
+        return collection.find(filter=search_filter)
+
     def _remove_from_list_and_return_document(self, search_filter: dict, remove_query: dict):
         collection = self._get_collection()
         return collection.find_one_and_update(
@@ -147,6 +164,10 @@ class MongoDBConnector(AbstractDocumentDBConnector):
             upsert=True,
         )
 
+    def aggregate(self, pipeline: List[Dict[str, Any]]) -> CommandCursor:
+        collection = self._get_collection(collection_name=self._db_config.COLLECTION)
+        return collection.aggregate(pipeline=pipeline)
+
     def ping(self):
         db = self.client.get_database(self._db_config.DATABASE_NAME)
         return db.command("ping")
