@@ -388,20 +388,24 @@ class S3Connector(ILogger):
         return bucket_objects
 
     @explicit_params_validation(validation_type="NoneOrEmpty")
-    def create_presigned_upload_url(self, object_name: str, fields=None, conditions=None, expiration=3600):
+    def create_presigned_upload_url(
+        self, object_name: str, fields=None, conditions=None, expiration=3600, override: bool = False
+    ):
         """Generate a presigned URL S3 POST request to upload a file
         :param object_name: string
         :param fields: Dictionary of prefilled form fields
         :param conditions: List of conditions to include in the policy
         :param expiration: Time in seconds for the presigned URL to remain valid
+        :param override: Allows disregarding the existence of an object in S3
         :return: Dictionary with the following keys:
             url: URL to post to
             fields: Dictionary of form fields and values to submit with the POST request
         """
         # https://boto3.amazonaws.com/v1/documentation/api/latest/guide/s3-presigned-urls.html#generating-a-presigned-url-to-upload-a-file
-        file_already_exist = self.check_key_exists(object_name)
-        if file_already_exist:
-            raise FileExistsError(f"The key {object_name} already exists in bucket {self.bucket_name}")
+        if not override:
+            file_already_exist = self.check_key_exists(object_name)
+            if file_already_exist:
+                raise FileExistsError(f"The key {object_name} already exists in bucket {self.bucket_name}")
 
         response = self.s3_client.generate_presigned_post(
             self.bucket_name, object_name, Fields=fields, Conditions=conditions, ExpiresIn=expiration
