@@ -50,6 +50,19 @@ class DBInterface(Generic[T], ILogger):
             )
         return self._element_type(**updated_element)
 
+    def update_many(self, updated_document: Dict[str, Any], search_filter: Dict[str, Any] = {}) -> List[T]:
+        """
+        Updates multiple elements in the DB using the specified search filter
+        :param updated_document: the new values to set for the documents
+        :param search_filter: documents to update values for
+        :return: List[T]
+        """
+        with self._db_connector as db:
+            elements = db._update_many_and_return_documents(
+                search_filter=search_filter, updated_document=updated_document
+            )
+        return [self._element_type(**element) for element in elements]
+
     def delete(self, id: UUID, force: bool = False) -> bool:
         """
         Deletes an element from the DB
